@@ -17,10 +17,11 @@ package main
 
 import (
 	"testing"
+	"time"
 
 	"github.com/phayes/freeport"
 	"go.uber.org/zap/zapcore"
-	"knative.dev/eventing/test/lib"
+	testlib "knative.dev/eventing/test/lib"
 	"knative.dev/eventing/test/upgrade/prober/wathola/config"
 	"knative.dev/eventing/test/upgrade/prober/wathola/receiver"
 
@@ -32,8 +33,9 @@ func TestReceiverMain(t *testing.T) {
 	config.Instance.LogLevel = zapcore.DebugLevel
 	config.Instance.Receiver.Port = port
 	go main()
+	time.Sleep(time.Millisecond)
 	cancel := <-receiver.Canceling
-	err := lib.WaitForReadiness(port)
+	err := testlib.WaitForReadiness(port, config.Log)
 	assert.NoError(t, err)
 	assert.NotNil(t, instance)
 
